@@ -6,5 +6,5 @@ from grokcore.security import require
 from dolmen.content.interfaces import *
 from dolmen.content.directives import schema, factory, nofactory
 from dolmen.content.base import Content, Container, OrderedContainer
-from dolmen.content.utils import get_content_type
+from dolmen.content.utils import get_content_type, get_schema
 from dolmen.content.factoring import Factory
